@@ -24,7 +24,7 @@ def blueprint_factory():
     swagger_blueprint.static(
         "/", dir_path + "/index.html", strict_slashes=True
     )
-    swagger_blueprint.static("/", dir_path)
+    swagger_blueprint.static("", dir_path)
 
     # Redirect "/swagger" to "/swagger/"
     @swagger_blueprint.route("", strict_slashes=True)
@@ -54,6 +54,8 @@ def blueprint_factory():
         for blueprint_name, handler in get_blueprinted_routes(app):
             route_spec = route_specs[handler]
             route_spec.blueprint = blueprint_name
+            if route_spec.exclude:
+                continue
             if not route_spec.tags:
                 route_spec.tags.append(blueprint_name)
 
@@ -177,7 +179,8 @@ def blueprint_factory():
 
                 endpoint = remove_nulls(
                     {
-                        "operationId": route_spec.operation or route_name,
+                        "operationId": route_spec.operation
+                        or "%s_%s" % (_method.lower(), route_name),
                         "summary": route_spec.summary,
                         "description": route_spec.description,
                         "consumes": consumes_content_types,
@@ -195,7 +198,9 @@ def blueprint_factory():
                 methods[_method.lower()] = endpoint
 
             if methods:
-                paths[uri] = methods
+                if uri not in paths:
+                    paths[uri] = {}
+                paths[uri].update(methods)
 
         # --------------------------------------------------------------- #
         # Definitions
