@@ -1,11 +1,14 @@
 import json
+import typing as t
 from datetime import date, datetime, time
 from enum import Enum
-from typing import Any, Dict, List, Union, get_type_hints
+from inspect import isclass
+from typing import Any, Dict, List, Optional, Union, get_type_hints
 
 
 class Definition:
     __fields: dict
+    __nullable__: Optional[List[str]] = []
 
     def __init__(self, **kwargs):
         self.__fields = self.guard(kwargs)
@@ -22,19 +25,39 @@ class Definition:
         }
 
     def serialize(self):
-        return _serialize(self.fields)
+        return {
+            k: v
+            for k, v in _serialize(self.fields).items()
+            if (
+                v
+                or (
+                    isinstance(self.__nullable__, list)
+                    and (not self.__nullable__ or k in self.__nullable__)
+                )
+            )
+        }
 
     def __str__(self):
         return json.dumps(self.serialize())
 
+    def apply(self, func, operations, *args, **kwargs):
+        op = operations[func]
+        method_name = getattr(
+            self.__class__, "__method__", self.__class__.__name__.lower()
+        )
+        method = getattr(op, method_name)
+        if not args and not kwargs:
+            kwargs = self.__dict__
+        method(*args, **kwargs)
+
 
 class Schema(Definition):
     title: str
     description: str
     type: str
     format: str
-    nullable: False
-    required: False
+    nullable: bool
+    required: bool
     default: None
     example: None
     oneOf: List[Definition]
@@ -43,9 +66,9 @@ class Schema(Definition):
 
     multipleOf: int
     maximum: int
-    exclusiveMaximum: False
+    exclusiveMaximum: bool
     minimum: int
-    exclusiveMinimum: False
+    exclusiveMinimum: bool
     maxLength: int
     minLength: int
     pattern: str
@@ -104,14 +127,11 @@ class Schema(Definition):
 
             return Array(schema, **kwargs)
         elif _type == dict:
-            return Object(
-                {k: Schema.make(v) for k, v in value.items()}, **kwargs
-            )
+            return Object.make(value, **kwargs)
+        elif _type == t._GenericAlias and value.__origin__ == list:
+            return Array(Schema.make(value.__args__[0]), **kwargs)
         else:
-            return Object(
-                {k: Schema.make(v) for k, v in _properties(value).items()},
-                **kwargs,
-            )
+            return Object.make(value, **kwargs)
 
 
 class Boolean(Schema):
@@ -187,12 +207,19 @@ class Object(Schema):
     def __init__(self, properties: Dict[str, Schema] = None, **kwargs):
         super().__init__(type="object", properties=properties or {}, **kwargs)
 
+    @classmethod
+    def make(cls, value: Any, **kwargs):
+        return cls(
+            {k: Schema.make(v) for k, v in _properties(value).items()},
+            **kwargs,
+        )
+
 
 class Array(Schema):
     items: Any
     maxItems: int
     minItems: int
-    uniqueItems: False
+    uniqueItems: bool
 
     def __init__(self, items: Any, **kwargs):
         super().__init__(type="array", items=Schema.make(items), **kwargs)
@@ -216,10 +243,13 @@ def _serialize(value) -> Any:
 
 def _properties(value: object) -> Dict:
     try:
-        fields = {
-            x: v for x, v in value.__dict__.items() if not x.startswith("_")
-        }
+        fields = {x: v for x, v in value.__dict__.items()}
     except AttributeError:
-        return {}
+        fields = {}
 
-    return {**get_type_hints(value.__class__), **fields}
+    cls = value if isclass(value) else value.__class__
+    return {
+        k: v
+        for k, v in {**get_type_hints(cls), **fields}.items()
+        if not k.startswith("_")
+    }
